Crate utf8next

Crate utf8next 

Structs

NonEmptyStr
A str wrapper type that enforces that a string must be non-empty.

Functions

next_char_with_len
Returns the next character in the string with the length of the character in bytes.
next_char_with_len_inline
Returns the next character in the string with the length of the character in bytes.