Structs
- NonEmpty
Str - A str wrapper type that enforces that a string must be non-empty.
Functions
- next_
char_ with_ len - Returns the next character in the string with the length of the character in bytes.
- next_
char_ with_ len_ inline - Returns the next character in the string with the length of the character in bytes.